==> payara-embedded-all-4.1.1.171.1-sources.jar: org/glassfish/admin/rest/model/ResourceLink.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.admin.rest.model;

import java.net.URI;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;

/**
 * Describes a link from one resource to another resource.
 * Used to return links in response bodies.
 *
 * @author tmoreau
 */
public class ResourceLink {

    private String rel;
    private String title;
    private URI uri;

    public ResourceLink(String rel, String title, URI uri) {
        this.rel = rel;
        this.title = title;
        this.uri = uri;
    }

    public ResourceLink(String rel, URI uri) {
        this.rel = rel;
        this.uri = uri;
    }

    public URI getURI() {
        return this.uri;
    }

    public void setURI(URI val) {
        this.uri = val;
    }

    public String getRelationship() {
        return this.rel;
    }

    public void setRelationship(String val) {
        this.rel = val;
    }

    public String getTitle() {
        return this.title;
    }

    public void setTitle(String val) {
        this.title = val;
    }

    public JSONObject toJson() throws JSONException {
        JSONObject object = new JSONObject();
        object.put("rel", getRelationship());
        object.put("uri", getURI().toASCIIString());
        String t = getTitle();
        if (t != null && t.length() > 0) {
          object.put("title", t);
        }
        return object;
    }
}

==> payara-embedded-all-5.2020.4-sources.jar: org/glassfish/admin/rest/model/ResourceLink.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 *
 * Portions Copyright [2017] Payara Foundation and/or affiliates
 */
package org.glassfish.admin.rest.model;

import java.net.URI;
import javax.json.Json;
import javax.json.JsonException;
import javax.json.JsonObject;
import javax.json.JsonObjectBuilder;

/**
 * Describes a link from one resource to another resource.
 * Used to return links in response bodies.
 *
 * @author tmoreau
 */
public class ResourceLink {

    private String rel;
    private String title;
    private URI uri;

    public ResourceLink(String rel, String title, URI uri) {
        this.rel = rel;
        this.title = title;
        this.uri = uri;
    }

    public ResourceLink(String rel, URI uri) {
        this.rel = rel;
        this.uri = uri;
    }

    public URI getURI() {
        return this.uri;
    }

    public void setURI(URI val) {
        this.uri = val;
    }

    public String getRelationship() {
        return this.rel;
    }

    public void setRelationship(String val) {
        this.rel = val;
    }

    public String getTitle() {
        return this.title;
    }

    public void setTitle(String val) {
        this.title = val;
    }

    public JsonObject toJson() throws JsonException {
        JsonObjectBuilder object = Json.createObjectBuilder();
        object.add("rel", getRelationship());
        object.add("uri", getURI().toASCIIString());
        String t = getTitle();
        if (t != null && t.length() > 0) {
          object.add("title", t);
        }
        return object.build();
    }
}
